@@ -1,4 +1,4 @@
-// Copyright (c) 2016-2023 The Regents of the University of Michigan
+// Copyright (c) 2016-2024 The Regents of the University of Michigan
 // Part of GSD, released under the BSD 2-Clause License.
 
 #include <sys/stat.h>
@@ -1623,7 +1623,10 @@ int gsd_create(const char* fname,
                            O_RDWR | O_CREAT | O_TRUNC | extra_flags,
                            S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP);
     int retval = gsd_initialize_file(fd, application, schema, schema_version);
-    close(fd);
+    if (fd != -1)
+        {
+        close(fd);
+        }
     return retval;
     }
 
@@ -1670,14 +1673,20 @@ int gsd_create_and_open(struct gsd_handle* handle,
     int retval = gsd_initialize_file(handle->fd, application, schema, schema_version);
     if (retval != 0)
         {
-        close(handle->fd);
+        if (handle->fd != -1)
+            {
+            close(handle->fd);
+            }
         return retval;
         }
 
     retval = gsd_initialize_handle(handle);
     if (retval != 0)
         {
-        close(handle->fd);
+        if (handle->fd != -1)
+            {
+            close(handle->fd);
+            }
         }
     return retval;
     }
@@ -1712,7 +1721,10 @@ int gsd_open(struct gsd_handle* handle, const char* fname, const enum gsd_open_f
     int retval = gsd_initialize_handle(handle);
     if (retval != 0)
         {
-        close(handle->fd);
+        if (handle->fd != -1)
+            {
+            close(handle->fd);
+            }
         }
     return retval;
     }
@@ -2000,7 +2012,7 @@ int gsd_flush(struct gsd_handle* handle)
                 {
                 handle->frame_index.data[i]
                     = handle->frame_index
-                          .data[handle->frame_index.size - handle->pending_index_entries];
+                          .data[handle->frame_index.size - handle->pending_index_entries + i];
                 }
             }
 
