@@ -1,4 +1,4 @@
-# Copyright (c) 2016-2023 The Regents of the University of Michigan
+# Copyright (c) 2016-2024 The Regents of the University of Michigan
 # Part of GSD, released under the BSD 2-Clause License.
 
 """GSD reader written in pure Python.
@@ -29,15 +29,14 @@ The :py:class:`GSDFile` in this module can be used with the
 
 """
 
-from __future__ import print_function
-from __future__ import division
 import logging
-import numpy
 import struct
-from collections import namedtuple
 import sys
+from collections import namedtuple
 
-version = "3.0.1"
+import numpy
+
+version = '3.3.0'
 
 logger = logging.getLogger('gsd.pygsd')
 
@@ -50,8 +49,7 @@ gsd_header = namedtuple(
 )
 gsd_header_struct = struct.Struct('QQQQQII64s64s80s')
 
-gsd_index_entry = namedtuple('gsd_index_entry',
-                             'frame N location M id type flags')
+gsd_index_entry = namedtuple('gsd_index_entry', 'frame N location M id type flags')
 gsd_index_entry_struct = struct.Struct('QQqIHBB')
 
 gsd_type_mapping = {
@@ -68,7 +66,7 @@ gsd_type_mapping = {
 }
 
 
-class GSDFile(object):
+class GSDFile:
     """GSD file access interface.
 
     Implemented in pure Python and accepts any Python file-like object.
@@ -112,25 +110,24 @@ class GSDFile(object):
         try:
             header_raw = self.__file.read(gsd_header_struct.size)
         except UnicodeDecodeError:
-            print("\nDid you open the file in binary mode (rb)?\n",
-                  file=sys.stderr)
+            print('\nDid you open the file in binary mode (rb)?\n', file=sys.stderr)
             raise
 
         if len(header_raw) != gsd_header_struct.size:
-            raise IOError
+            raise OSError
 
         self.__header = gsd_header._make(gsd_header_struct.unpack(header_raw))
 
         # validate the header
-        if self.__header.magic != 0x65DF65DF65DF65DF:
-            raise RuntimeError("Not a GSD file: " + str(self.__file))
-        if (self.__header.gsd_version < (1 << 16)
-                and self.__header.gsd_version != (0 << 16 | 3)):
-            raise RuntimeError("Unsupported GSD file version: "
-                               + str(self.__file))
+        expected_magic = 0x65DF65DF65DF65DF
+        if self.__header.magic != expected_magic:
+            raise RuntimeError('Not a GSD file: ' + str(self.__file))
+        if self.__header.gsd_version < (1 << 16) and self.__header.gsd_version != (
+            0 << 16 | 3
+        ):
+            raise RuntimeError('Unsupported GSD file version: ' + str(self.__file))
         if self.__header.gsd_version >= (3 << 16):
-            raise RuntimeError("Unsupported GSD file version: "
-                               + str(self.__file))
+            raise RuntimeError('Unsupported GSD file version: ' + str(self.__file))
 
         # determine the file size (only works in Python 3)
         self.__file.seek(0, 2)
@@ -139,8 +136,7 @@ class GSDFile(object):
         self.__namelist = {}
         c = 0
         self.__file.seek(self.__header.namelist_location, 0)
-        namelist_raw = self.__file.read(self.__header.namelist_allocated_entries
-                                        * 64)
+        namelist_raw = self.__file.read(self.__header.namelist_allocated_entries * 64)
 
         names = namelist_raw.split(b'\x00')
 
@@ -157,20 +153,19 @@ class GSDFile(object):
         for i in range(self.__header.index_allocated_entries):
             index_entry_raw = self.__file.read(gsd_index_entry_struct.size)
             if len(index_entry_raw) != gsd_index_entry_struct.size:
-                raise IOError
+                raise OSError
 
-            idx = gsd_index_entry._make(
-                gsd_index_entry_struct.unpack(index_entry_raw))
+            idx = gsd_index_entry._make(gsd_index_entry_struct.unpack(index_entry_raw))
 
             # 0 location signifies end of index
             if idx.location == 0:
                 break
 
             if not self.__is_entry_valid(idx):
-                raise RuntimeError("Corrupt GSD file: " + str(self.__file))
+                raise RuntimeError('Corrupt GSD file: ' + str(self.__file))
 
             if i > 0 and idx.frame < self.__index[i - 1].frame:
-                raise RuntimeError("Corrupt GSD file: " + str(self.__file))
+                raise RuntimeError('Corrupt GSD file: ' + str(self.__file))
 
             self.__index.append(idx)
 
@@ -236,7 +231,7 @@ class GSDFile(object):
         R = len(self.__index)
 
         # progressively narrow the search window by halves
-        while (R - L > 1):
+        while R - L > 1:
             m = (L + R) // 2
 
             if frame < self.__index[m].frame:
@@ -266,7 +261,6 @@ class GSDFile(object):
             bool: True if the chunk exists in the file. False if it does not.
 
         Example:
-
             Handle non-existent chunks::
 
                 with GSDFile(open('file.gsd', mode='r')) as f:
@@ -276,7 +270,8 @@ class GSDFile(object):
                         return None
         """
         if not self.__is_open:
-            raise ValueError("File is not open")
+            msg = 'File is not open'
+            raise ValueError(msg)
 
         chunk = self._find_chunk(frame, name)
         return chunk is not None
@@ -319,38 +314,51 @@ class GSDFile(object):
             arrays instead.
         """
         if not self.__is_open:
-            raise ValueError("File is not open")
+            msg = 'File is not open'
+            raise ValueError(msg)
 
         chunk = self._find_chunk(frame, name)
 
         if chunk is None:
-            raise KeyError("frame " + str(frame) + " / chunk " + name
-                           + " not found in: " + str(self.__file))
+            raise KeyError(
+                'frame '
+                + str(frame)
+                + ' / chunk '
+                + name
+                + ' not found in: '
+                + str(self.__file)
+            )
 
-        logger.debug('read chunk: ' + str(self.__file) + ' - ' + str(frame)
-                     + ' - ' + name)
+        logger.debug(
+            'read chunk: ' + str(self.__file) + ' - ' + str(frame) + ' - ' + name
+        )
 
         size = chunk.N * chunk.M * gsd_type_mapping[chunk.type].itemsize
         if chunk.location == 0:
-            raise RuntimeError("Corrupt chunk: " + str(frame) + " / " + name
-                               + " in file" + str(self.__file))
+            raise RuntimeError(
+                'Corrupt chunk: '
+                + str(frame)
+                + ' / '
+                + name
+                + ' in file'
+                + str(self.__file)
+            )
 
-        if (size == 0):
+        if size == 0:
             return numpy.array([], dtype=gsd_type_mapping[chunk.type])
 
         self.__file.seek(chunk.location, 0)
         data_raw = self.__file.read(size)
 
         if len(data_raw) != size:
-            raise IOError
+            raise OSError
 
-        data_npy = numpy.frombuffer(data_raw,
-                                    dtype=gsd_type_mapping[chunk.type])
+        data_npy = numpy.frombuffer(data_raw, dtype=gsd_type_mapping[chunk.type])
 
         if chunk.M == 1:
             return data_npy
-        else:
-            return data_npy.reshape([chunk.N, chunk.M])
+
+        return data_npy.reshape([chunk.N, chunk.M])
 
     def find_matching_chunk_names(self, match):
         """Find chunk names in the file that start with the string *match*.
@@ -406,7 +414,7 @@ class GSDFile(object):
         The tuple is in the order (major, minor).
         """
         v = self.__header.gsd_version
-        return (v >> 16, v & 0xffff)
+        return (v >> 16, v & 0xFFFF)
 
     @property
     def schema_version(self):
@@ -415,7 +423,7 @@ class GSDFile(object):
         The tuple is in the order (major, minor).
         """
         v = self.__header.schema_version
-        return (v >> 16, v & 0xffff)
+        return (v >> 16, v & 0xFFFF)
 
     @property
     def schema(self):
@@ -431,9 +439,10 @@ class GSDFile(object):
     def nframes(self):
         """int: Number of frames in the file."""
         if not self.__is_open:
-            raise ValueError("File is not open")
+            msg = 'File is not open'
+            raise ValueError(msg)
 
         if len(self.__index) == 0:
             return 0
-        else:
-            return self.__index[-1].frame + 1
+
+        return self.__index[-1].frame + 1
